@@ -1,7 +1,8 @@
 use strict;
 use warnings;
 
-package Scalar::Boolean::Tie;
+package    #private
+  Scalar::Boolean::Tie;
 
 use Tie::Scalar;
 use base qw( Tie::StdScalar );
@@ -47,7 +48,7 @@ Scalar::Boolean::Tie
 
 =head1 VERSION
 
-version 1.00
+version 1.02
 
 =head1 AUTHOR
 
@@ -55,7 +56,7 @@ Alan Haggai Alavi <alanhaggai@alanhaggai.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Alan Haggai Alavi.
+This software is copyright (c) 2012 by Alan Haggai Alavi.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
